/*
 * Copyright (C) 2009 Igalia S.L.
 *
 * Contact: Iago Toral Quiroga <itoral@igalia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef _MAFW_FS_SOURCE_H_
#define _MAFW_FS_SOURCE_H_


#include <glib.h>
#include <glib-object.h>

#include <libmafw/mafw.h>
#include <libmafw/mafw-source.h>
#include <libmafw/mafw-metadata.h>

G_BEGIN_DECLS

/* GObject macros */

#define MAFW_TYPE_FS_SOURCE (mafw_fs_source_get_type ())
#define MAFW_FS_SOURCE(obj)						\
	(G_TYPE_CHECK_INSTANCE_CAST ((obj),				\
				     MAFW_TYPE_FS_SOURCE, MafwFsSource))
#define MAFW_IS_FS_SOURCE(obj)						\
        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MAFW_TYPE_FS_SOURCE))
#define MAFW_FS_SOURCE_CLASS(klass)                            \
        (G_TYPE_CHECK_CLASS_CAST((klass), MAFW_TYPE_FS_SOURCE, \
                                 MafwFsSourceClass))
#define MAFW_IS_FS_SOURCE_CLASS(klass)				\
        (G_TYPE_CHECK_CLASS_TYPE((klass), MAFW_TYPE_FS_SOURCE))
#define MAFW_FS_SOURCE_GET_CLASS(obj)                           \
        (G_TYPE_INSTANCE_GET_CLASS ((obj), MAFW_TYPE_FS_SOURCE, \
                                    MafwFsSourceClass))

/* Plugin Name, not really important */
#define MAFW_FS_SOURCE_PLUGIN_NAME "MAFW-Filesystem-Source-Plugin"

/* Source name, to be used in the GUI */
#define MAFW_FS_SOURCE_NAME "MAFW FileSystem Source"

/* Source UUID, an internal identifier (must be unique for each source)  */
#define MAFW_FS_SOURCE_UUID "mafwfssrc"

/* GObject definition */
typedef struct _MafwFsSource MafwFsSource;
typedef struct _MafwFsSourceClass MafwFsSourceClass;
typedef struct _MafwFsSourcePrivate MafwFsSourcePrivate;

struct _MafwFsSource {
        MafwSource parent;

        /* private */
        MafwFsSourcePrivate *priv;
};

struct _MafwFsSourceClass {
        MafwSourceClass parent_class;
};

GType mafw_fs_source_get_type (void);
gboolean mafw_fs_source_plugin_initialize (MafwRegistry * registry, GError **error);
void mafw_fs_source_plugin_deinitialize (GError **error) ;

G_END_DECLS

#endif
